@@ -57,6 +57,8 @@
  *                      CTAXT_FATAL_ERROR and leave the error message in a
  *                      dynamic Tcl string maintained by the module.
  *                      Wrote functions to get and check software versions
+ *  14.01.1994  hp      Fixed some bugs of incorrect casts like
+ *                        (Tk_EventProc) proc --> (Tk_EventProc *) proc
  */
 
 
@@ -554,7 +556,7 @@ CTAXT_PutTclTkInWindow (mainWin,win,disp,interpName,script,argc,argv)
 #if CTAXT_DEBUG_LEVEL > 0
   fprintf (stderr,"\nBefore Tk_CreateGenericHandler()\n");
 #endif
-    Tk_CreateGenericHandler ((Tk_GenericProc) CTAXT_FirstEventHandler,
+    Tk_CreateGenericHandler ((Tk_GenericProc *) CTAXT_FirstEventHandler,
 			     (ClientData) &CTAXT_Global);
 #if CTAXT_DEBUG_LEVEL > 0
   fprintf (stderr,"\nAfter Tk_CreateGenericHandler()\n");
@@ -592,7 +594,7 @@ CTAXT_PutTclTkInWindow (mainWin,win,disp,interpName,script,argc,argv)
 
   Tk_CreateEventHandler (tkwin,
 			 EnterWindowMask | LeaveWindowMask,
-			 (Tk_EventProc) CTAXT_KeepTrackOfFocus,
+			 (Tk_EventProc *) CTAXT_KeepTrackOfFocus,
 			 (ClientData) &CTAXT_Global);
 
 
@@ -833,7 +835,7 @@ CTAXT_MainLoop ()
   fprintf (stderr,"\nBefore Tk_DeleteGenericHandler()\n");
 #endif
 
-  Tk_DeleteGenericHandler ((Tk_GenericProc) CTAXT_FirstEventHandler,
+  Tk_DeleteGenericHandler ((Tk_GenericProc *) CTAXT_FirstEventHandler,
 			   (ClientData) &CTAXT_Global);
 
 #if CTAXT_DEBUG_LEVEL > 0
@@ -852,7 +854,7 @@ CTAXT_MainLoop ()
   fprintf (stderr,"\nBefore Tk_CreateGenericHandler()\n");
 #endif
 
-  Tk_CreateGenericHandler ((Tk_GenericProc) CTAXT_EventHandler,
+  Tk_CreateGenericHandler ((Tk_GenericProc *) CTAXT_EventHandler,
 			   (ClientData) &CTAXT_Global);
 
 #if CTAXT_DEBUG_LEVEL > 0
@@ -877,7 +879,7 @@ CTAXT_MainLoop ()
   fprintf (stderr,"\nBefore Tk_DeleteGenericHandler()\n");
 #endif
 
-  Tk_DeleteGenericHandler ((Tk_GenericProc) CTAXT_EventHandler,
+  Tk_DeleteGenericHandler ((Tk_GenericProc *) CTAXT_EventHandler,
 			   (ClientData) &CTAXT_Global);
 
 #if CTAXT_DEBUG_LEVEL > 0
