@@ -77,6 +77,15 @@
  *                      extensions to CTAXT_DeleteInterpreter().
  *                      Removing event handlers CTAXT_KeepTrackOfFocus(), when
  *                      the Tk window is destroyed.
+ *  14.01.1994  hp      Defined forward references for functions 
+ *                      CTAXT_KeepTrackOfFocus() and CTAXT_DeleteInterpreter()
+ *                      Fixed some bugs of incorrect casts like
+ *                        (Tk_EventProc) proc --> (Tk_EventProc *) proc
+ *                      Fixed the bug in the parameter definition of 
+ *                      CTAXT_GetAbsCoords(): 
+ *                         Tk_Window *tkwin; --> Tk_Window tkwin;
+ *                      Corrected the forward references of 
+ *                      CTAXT_GetAbsCoords() and CTAXT_MoveResizeMainWindow()
  *
  */
 
@@ -106,8 +115,11 @@ typedef struct {
  *  Prototypes for forward references
  */
 
-static void CTAXT_GetAbsCoords _ANSI_ARGS_ ((Tk_Window *tkwin));
-int CTAXT_MoveResizeMainWindow _ANSI_ARGS_ ((Tk_Window *tkwin));
+void CTAXT_KeepTrackOfFocus _ANSI_ARGS_ ((ClientData clientData,
+                                          XEvent *eventPtr));
+static void CTAXT_DeleteInterpreter _ANSI_ARGS_ ((ClientData clientData));
+static void CTAXT_GetAbsCoords _ANSI_ARGS_ ((Tk_Window tkwin));
+int CTAXT_MoveResizeMainWindow _ANSI_ARGS_ ((Tk_Window tkwin));
 static void CTAXT_DeleteInterpreter _ANSI_ARGS_ ((ClientData clientData));
 
 
@@ -233,7 +245,7 @@ CTAXT_DeleteInterpreter (clientData)
 
   Tk_DeleteEventHandler (info->tkWin,
 			 EnterWindowMask | LeaveWindowMask,
-			 (Tk_EventProc) CTAXT_KeepTrackOfFocus,
+			 (Tk_EventProc *) CTAXT_KeepTrackOfFocus,
 			 (ClientData) info->data);
 
 #if CTAXT_DEBUG_LEVEL > 0
@@ -476,7 +488,7 @@ CTAXT_FirstEventHandler (clientData,event)
 		   i+1);
 #endif
 
-	  Tk_DoWhenIdle ((Tk_IdleProc) CTAXT_DeleteInterpreter,
+	  Tk_DoWhenIdle ((Tk_IdleProc *) CTAXT_DeleteInterpreter,
 			 (ClientData) info);
 
 	}  /*  Matches  if ((info = (CTAXT_DelInfo *) calloc (...)) != NULL) */
@@ -741,7 +753,7 @@ CTAXT_EventHandler (clientData,event)
 		   i+1);
 #endif
 
-	  Tk_DoWhenIdle ((Tk_IdleProc) CTAXT_DeleteInterpreter,
+	  Tk_DoWhenIdle ((Tk_IdleProc *) CTAXT_DeleteInterpreter,
 			 (ClientData) info);
 
 	}  /*  Matches  if ((info = (CTAXT_DelInfo *) calloc (...)) != NULL) */
@@ -848,7 +860,7 @@ CTAXT_EventHandler (clientData,event)
 
 static void
 CTAXT_GetAbsCoords(tkwin)
-  Tk_Window  *tkwin;
+  Tk_Window  tkwin;
 {
   TkWindow               *winPtr = ((TkWindow *) tkwin);
   XWindowAttributes      xattrbs;
