@@ -67,6 +67,9 @@
  *                      fixed a bug in the call to Tk_CreateMainWindow(), the
  *                      function was called with one more argument than 
  *                      necessary (which didn't cause a problem)
+ *  14.01.1994  hp      Corrected the function prototype definition of
+ *                      CTAXT_MoveResizeMainWindow()
+ *                      Got rid of redundant include of file "tkConfig.h"
  *
  *
  *
@@ -104,7 +107,15 @@
 
 
 
-#include <tkConfig.h>
+/*
+ *  the source from which this file is inherited (tkWindow.c) includes
+ *  "tkConfig.h" before any other file is included. This caused some problems
+ *  with conflicting types, e.g. "select" (probably because my auto-
+ *  configuration script does not create all the necessary defines needed for
+ *  including that file). However, "tkConfig.h" does not define anything that
+ *  is used or needed within this file hence, I got rid of that include!
+ */
+
 #include <tkInt.h>
 #include <patchlevel.h>
 #include "ctaxtInt.h"
@@ -228,7 +239,7 @@ static TkDisplay *CTAXT_GetScreen _ANSI_ARGS_((Tcl_Interp *interp,
 static TkWindow *CTAXT_NewWindow _ANSI_ARGS_ ((TkDisplay *dispPtr,
 					       int screenNum,
 					       Window window));
-int CTAXT_MoveResizeMainWindow _ANSI_ARGS_ ((Tk_Window *tkwin));
+int CTAXT_MoveResizeMainWindow _ANSI_ARGS_ ((Tk_Window tkwin));
 
 
 
